Quote

Trait Quote 

pub trait Quote<OUT: Default>: QuoteInto<OUT> {
    // Provided method
    fn quote<'q, S: Into<Quotable<'q>>>(s: S) -> OUT { ... }
}
Quoting/escaping a string of bytes into a shell-safe form.

Provided Methods

fn quote<'q, S: Into<Quotable<'q>>>(s: S) -> OUT

Quote/escape a string of bytes into a new container.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T: QuoteInto<OUT>, OUT: Default> Quote<OUT> for T

Blanket Quote impl for anything that has a QuoteInto impl.